@@ -21,7 +21,7 @@ from argparse import ArgumentTypeError
 from collections import namedtuple
 from testflows._core.exceptions import exception
 from testflows._core.compress import CompressedFile
-from testflows._core.funcs import repeat as Repeat
+from testflows._core.objects import RepeatTest
 
 KeyValue = namedtuple("KeyValue", "key value")
 
@@ -131,8 +131,8 @@ def count(value):
 
 def repeat(value):
     try:
-        fields = list(csv.reader([value],"unix"))[-1]
-        option = Repeat(*fields)
+        fields = list(csv.reader([value], "unix"))[-1]
+        option = RepeatTest(*fields)
     except Exception as e:
         raise ArgumentTypeError(f"'{value}' is invalid")
     return option
@@ -141,7 +141,7 @@ def tags_filter(value):
     try:
         type, cvstags = value.split(":", 1)
         assert type in ["test", "suite", "module", "feature", "scenario"]
-        tags = list(csv.reader([cvstags],"unix"))[-1]
+        tags = list(csv.reader([cvstags], "unix"))[-1]
         if type == "scenario":
             type = "test"
         elif type == "feature":
