@@ -167,6 +167,9 @@ class Tag(TestObject):
         self.value = value
         return super(Tag, self).__init__()
 
+    def __str__(self):
+        return str(self.value)
+
 class Argument(TestObject):
     _fields = ("name", "value", "type", "group", "uid")
     _defaults = (None,) * 4
@@ -283,11 +286,15 @@ class ExamplesRow(TestObject):
 class ExamplesTable(Table):
     _row_type_name = "Example"
 
-    def __new__(cls, header=None, rows=None, row_format=None):
+    def __new__(cls, header=None, rows=None, row_format=None, args=None):
         if rows is None:
             rows = []
         if header is None:
             header = ""
+        if args is None:
+            args = {}
+        else:
+            args = dict(args)
 
         row_type = namedtuple(cls._row_type_name, header)
 
@@ -315,6 +322,9 @@ class ExamplesTable(Table):
         for idx, row in enumerate(obj):
             row._idx = idx
             row._row_format = obj.row_format
+
+        obj.args = args
+
         return obj
 
 class NamedValue(object):
@@ -335,6 +345,10 @@ class NamedValue(object):
         setattr(func, self.name, self.value)
         return func
 
+class NamedString(NamedValue):
+    def __str__(self):
+        return str(self.value)
+
 class NamedList(list):
     name = None
 
@@ -456,31 +470,25 @@ class Tags(NamedList):
     def __init__(self, *tags):
         super(Tags, self).__init__(*tags)
 
-class Uid(object):
-    def __init__(self, uid):
-        self.uid = uid
+class Uid(NamedString):
+    name = "uid"
 
-    def __call__(self, func):
-        func.uid = self.uid
-        return func
+class ArgumentParser(NamedValue):
+    name = "argparser"
 
-class ArgumentParser(object):
     def __init__(self, parser):
-        self.argparser = parser
+        self.value = parser
 
-    def __call__(self, func):
-        func.argparser = self.argparser
-        return func
-
-class Name(NamedValue):
+class Name(NamedString):
     name = "name"
 
-class Description(NamedValue):
+class Description(NamedString):
     name = "description"
 
 class Examples(ExamplesTable):
-    def __new__(cls, header, rows, row_format=None):
-        return super(Examples, cls).__new__(cls, header=header, rows=rows, row_format=row_format)
+    def __new__(cls, header, rows, row_format=None, args=None):
+        return super(Examples, cls).__new__(cls, header=header,
+            rows=rows, row_format=row_format, args=args)
 
     def __call__(self, func):
         func.examples = self
